package sentio

import (
	"time"
)

type Market interface {
	Clock() Clock
	IsOpen() bool

	Connect(done chan struct{}) (chan MarketConnection, error)
	Subscribe(symbols ...string) error

	Account() (MarketAccount, error)
	MaxBudget() float64

	CreateOrder(symbol string, limit float64, quantity uint, rm RiskManager) (Order, error)
	UpdateOrder(orderID string, rm RiskManager) error
	CloseOrder(order Order, recommended *float64) (float64, error)

	Order(orderID string, nested bool) (Order, error)
	Orders(criteria OrderListCriteria) ([]Order, error)
	Portfolio() (Portfolio, error)
	PortfolioHistory() ([]PortfolioRecord, error)
	Quotes() (map[string]Quote, error)
	HistoricalBars(interval time.Duration, from *time.Time) (map[string][]Bar, error)
}
